# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import hr_employee
from . import account_move
from . import account_move_line
from . import account_payment
from . import account_tax
from . import hr_department
from . import hr_expense
from . import hr_expense_sheet
from . import ir_attachment
from . import product_product
from . import product_template
from . import res_config_settings
from . import res_company
from . import analytic
from . import ir_actions_report
